@@ -647,8 +647,6 @@ package Cfn::Resource {
     return @matches == 1;
   }
 
-  has AttributeList => (isa => 'ArrayRef[Str]', is => 'ro', lazy => 1, builder => '_build_attributes');
-
   sub DependsOnList {
     my $self = shift;
     return () if (not defined $self->DependsOn);
@@ -878,11 +876,13 @@ package Cfn {
   use Moose;
   use Moose::Util;
   use Scalar::Util;
+  use Cfn::ResourceModules;
+
   has AWSTemplateFormatVersion => (isa => 'Str', is => 'rw');
   has Description => (isa => 'Str', is => 'rw');
   has Transform => (isa => 'Cfn::Transform', is => 'rw', coerce => 1);
 
-  our $VERSION = '0.02';
+  our $VERSION = '0.03';
 
   has Parameters => (
     is => 'rw',
@@ -959,13 +959,13 @@ package Cfn {
     default => sub { Cfn::Internal::Options->new },
   );
 
-  use Module::Runtime qw//;
+  sub list_resource_modules {
+    return Cfn::ResourceModules::list();
+  }
+
   sub load_resource_module {
     my (undef, $type) = @_;
-    my $cfn_resource_class = "Cfn::Resource::$type";
-    my $retval = Module::Runtime::require_module($cfn_resource_class);
-    die "Couldn't load $cfn_resource_class" if (not $retval);
-    return $cfn_resource_class;
+    return Cfn::ResourceModules::load($type);
   }
 
   sub ResourcesOfType {
@@ -1651,11 +1651,19 @@ Holds the UpdatePolicy. Validates that the UpdatePolicy is valid
 
 HashRef with the CreationPolicy. Doesn't validate CreationPolicies.
 
+=head2 Methods for Cfn::Resource objects
+
 =head3 AttributeList
 
-Holds a Hashref of attributes that can be recalled in CloudFormation via C<Fn::GetAtt>
+Returns an ArrayRef of attributes that can be recalled in CloudFormation via C<Fn::GetAtt>.
 
-=head2 Methods for Cfn::Resource objects
+Can also be retrieved as a class method C<Cfn::Resource::...->AttributeList>
+
+=head3 supported_regions
+
+Returns an ArrayRef of the AWS regions where the resource can be provisioned.
+
+Can also be retrieved as a class method C<Cfn::Resource::...->supported_regions>
 
 =head3 DependsOnList
 
@@ -1666,7 +1674,8 @@ if the DependsOn attribute is a String or an ArrayRef of Strings.
 
 =head3 hasAttribute($attribute)
 
-Returns true if the specified attribute is in the C<AttributeList>
+Returns true if the specified attribute is in the C<AttributeList>. Note that some resources
+(AWS::CloudFormation::CustomResource) can return true for values that are not in AttributeList
 
 =head3 as_hashref
 
@@ -1770,6 +1779,8 @@ Returns a HashRef representation of the output that is convertible to JSON
 
 L<https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/template-anatomy.html>
 
+This module kind of resembles troposphere (python): L<https://github.com/cloudtools/troposphere>.
+
 =head1 AUTHOR
 
     Jose Luis Martinez
